@@ -82,7 +82,7 @@ is automatically created when you create a table.
 
 =cut
 
-sub insert {shift->_not_available}
+sub insert {return shift->_not_available}
 
 =head2 delete
 
@@ -91,7 +91,7 @@ when the meeting itself is deleted.
 
 =cut
 
-sub delete {shift->_not_available}
+sub delete {return shift->_not_available}
 
 =head2 list
 
@@ -100,7 +100,7 @@ to create a meeting, then retrieve on meeting id
 
 =cut
 
-sub list {shift->_not_available}
+sub list {return shift->_not_available}
 
 =head2 update
 
@@ -122,8 +122,7 @@ retrieved via this entity, but must be updated via Elive::Entity::Meeting.
 =cut
 
 sub update {
-    my $self = shift;
-    my $update_data = shift;
+    my ($self, $update_data, @args) = @_;
 
     $self->set( %$update_data)
 	if (keys %$update_data);
@@ -152,7 +151,7 @@ sub update {
     # This adapter barfs if we don't write values back, whether they've
     # changed or not.
     #
-    $self->SUPER::update(undef, @_, changed => [sort keys %changed]);
+    return $self->SUPER::update(undef, @args, changed => [sort keys %changed]);
 }
 
 =head1 See Also
